@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -26,9 +26,7 @@ public:
         lay->addWidget(label);
     }
 
-    ~ProgressIndicatorLabelPrivate()
-    {
-    }
+    ~ProgressIndicatorLabelPrivate() = default;
 
     void setActiveLabel(const QString &str)
     {
